summaryrefslogtreecommitdiffstats
path: root/src/H5F.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5F.c')
-rw-r--r--src/H5F.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/H5F.c b/src/H5F.c
index 50473fe..b623491 100644
--- a/src/H5F.c
+++ b/src/H5F.c
@@ -1059,15 +1059,15 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5Fget_fileno(hid_t file_id, unsigned long *fileno)
+H5Fget_fileno(hid_t file_id, unsigned long *fnumber)
{
herr_t ret_value = SUCCEED;
FUNC_ENTER_API(FAIL)
- H5TRACE2("e", "i*Ul", file_id, fileno);
+ H5TRACE2("e", "i*Ul", file_id, fnumber);
- /* If no fileno pointer was passed in, exit quietly */
- if(fileno) {
+ /* If no fnumber pointer was passed in, exit quietly */
+ if(fnumber) {
H5VL_object_t *vol_obj; /* File info */
/* Get the internal file structure */
@@ -1075,7 +1075,7 @@ H5Fget_fileno(hid_t file_id, unsigned long *fileno)
HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid file identifier")
/* Get the flags */
- if((ret_value = H5VL_file_get(vol_obj, H5VL_FILE_GET_FILENO, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL, fileno)) < 0)
+ if((ret_value = H5VL_file_get(vol_obj, H5VL_FILE_GET_FILENO, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL, fnumber)) < 0)
HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to get file's 'file number'")
} /* end if */